"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpObject = void 0;
const cookie_1 = require("cookie");
class HttpObject {
    constructor() {
        this.headers = {};
        this.cookies = {};
    }
    setCookie(name, value, options) {
        this.setHeader('set-cookie', (0, cookie_1.serialize)(name, value, options));
        this.cookies[name] = value;
    }
    getCookie(name) {
        if (this.cookies[name])
            return this.cookies[name];
        const cookieHeader = this.getHeader('cookie');
        if (cookieHeader) {
            const cookies = (0, cookie_1.parse)(String(cookieHeader));
            return cookies[name];
        }
    }
    setHeader(name, value) {
        const _name = name.toLowerCase();
        const current = this.headers[_name];
        if (current) {
            if (typeof current === 'string') {
                this.headers[_name] = [current, value];
                return;
            }
            this.headers[_name] = [...current, value];
            return;
        }
        this.headers[_name] = value;
    }
    getHeader(name) {
        return this.headers[name.toLowerCase()];
    }
}
exports.HttpObject = HttpObject;
