import { HttpHandler } from './HttpHandler';
import { HttpRequest } from './HttpRequest';
import { HttpResponse } from './HttpResponse';
export interface ServerOptions {
    uploadDir?: string;
    mapQueryToParams?: boolean;
    mapBodyToParams?: boolean;
}
type HttpErrorFn = (request: HttpRequest, response: HttpResponse, error: Error) => HttpResponse | Promise<HttpResponse>;
export declare abstract class Server {
    protected onError?: HttpErrorFn;
    config: ServerOptions;
    constructor(config: ServerOptions);
    protected abstract on(method: 'get' | 'post' | 'patch' | 'delete' | 'options' | 'put', path: string, middlewares: Array<HttpHandler>): void;
    abstract listen(port: number, callback: () => void): void;
    abstract close(): Promise<void>;
    setErrorHandler(onError: HttpErrorFn): void;
    get(path: string, ...middlewares: Array<HttpHandler>): void;
    post(path: string, ...middlewares: Array<HttpHandler>): void;
    put(path: string, ...middlewares: Array<HttpHandler>): void;
    patch(path: string, ...middlewares: Array<HttpHandler>): void;
    del(path: string, ...middlewares: Array<HttpHandler>): void;
    opts(path: string, ...middlewares: Array<HttpHandler>): void;
}
export {};
//# sourceMappingURL=Server.d.ts.map